Re: [PATCH v2 0/2] do_compare_entry: use already-computed path
- From
David Turner <dturner@twopensource.com>
- Date
- Dec 21, 2015, 23:33 UTC
- Message-ID
- <1450740784.3892.3.camel@twopensource.com>
- In-Reply-To
- <xmqqzix3e61h.fsf@gitster.mtv.corp.google.com>
On Mon, 2015-12-21 at 15:27 -0800, Junio C Hamano wrote:
> Thanks. Does the number still stay at 25% improvement?
Yes.